@@ -46,6 +46,8 @@ struct _PpsDocumentPrivate {
 	gchar **page_labels;
 	PpsPageSize *page_sizes;
 
+	gint n_pages;
+
 	GWeakRef *cached_pages;
 	/* the last page that was requested through pps_document_get_page
 	is saved, it optimizes cases where the same page is repeatedly queried */
@@ -88,12 +90,17 @@ pps_document_finalize (GObject *object)
 {
 	PpsDocument *document = PPS_DOCUMENT (object);
 	PpsDocumentPrivate *priv = GET_PRIVATE (document);
+	gint n_pages = pps_document_get_n_pages (document);
 
 	g_clear_pointer (&priv->uri, g_free);
 	g_clear_pointer (&priv->page_sizes, g_free);
 	g_clear_pointer (&priv->page_labels, g_strfreev);
 
 	g_clear_object (&priv->last_page);
+
+	for (int j = 0; j < n_pages; j++) {
+		g_weak_ref_clear (&priv->cached_pages[j]);
+	}
 	g_clear_pointer (&priv->cached_pages, g_free);
 
 	G_OBJECT_CLASS (pps_document_parent_class)->finalize (object);
@@ -142,6 +149,8 @@ pps_document_init (PpsDocument *document)
 
 	/* Assume all pages are the same size until proven otherwise */
 	priv->uniform = TRUE;
+
+	priv->n_pages = -1;
 }
 
 static void
@@ -504,14 +513,24 @@ _pps_document_get_size (const char *uri)
 	return size;
 }
 
+/**
+ * pps_document_get_n_pages:
+ * @document: a #PpsDocument
+ *
+ * Returns: the number of pages of the document. This is constant throughout
+ * the lifetime of the document.
+ */
 gint
 pps_document_get_n_pages (PpsDocument *document)
 {
 	g_return_val_if_fail (PPS_IS_DOCUMENT (document), 0);
+	PpsDocumentPrivate *priv = GET_PRIVATE (document);
 
-	PpsDocumentClass *klass = PPS_DOCUMENT_GET_CLASS (document);
-
-	return klass->get_n_pages (document);
+	if (priv->n_pages < 0) {
+		PpsDocumentClass *klass = PPS_DOCUMENT_GET_CLASS (document);
+		priv->n_pages = klass->get_n_pages (document);
+	}
+	return priv->n_pages;
 }
 
 /**
