@@ -3,10 +3,12 @@ use crate::deps::*;
 use papers_document::{LinkDest, LinkDestType};
 use papers_view::Job;
 
-use crate::config::RESOURCES_DATA;
-
+use git_version::git_version;
 use std::env;
 use std::ffi::OsString;
+use std::ops::ControlFlow;
+
+const RESOURCES_DATA: &[u8] = include_bytes!(env!("PAPERS_RESOURCES_FILE"));
 
 mod imp {
     use super::*;
@@ -42,7 +44,7 @@ mod imp {
             papers_document::init();
 
             // Manually set name and icon
-            glib::set_application_name(&gettext("Papers"));
+            glib::set_application_name(&gettext("Document Viewer"));
             gtk::Window::set_default_icon_name(APP_ID);
 
             self.setup_actions();
@@ -62,14 +64,18 @@ mod imp {
             }
         }
 
-        fn handle_local_options(&self, options: &glib::VariantDict) -> glib::ExitCode {
+        fn handle_local_options(&self, options: &glib::VariantDict) -> ControlFlow<glib::ExitCode> {
             // print the version in local instance rather than sending it to primary
             if options.contains("version") {
-                glib::g_print!("{} {}\n", gettext("Papers"), crate::config::VERSION);
-                return 0.into();
+                glib::g_print!(
+                    "{} {}\n",
+                    gettext("Papers Document Viewer"),
+                    crate::config::VERSION
+                );
+                return ControlFlow::Break(glib::ExitCode::SUCCESS);
             }
 
-            (-1).into()
+            ControlFlow::Continue(())
         }
 
         fn command_line(&self, command_line: &gio::ApplicationCommandLine) -> glib::ExitCode {
@@ -127,25 +133,23 @@ mod imp {
 
     impl PpsApplication {
         fn parse_dest(&self, uri: &str) -> Option<papers_document::LinkDest> {
-            if papers_document::file_get_mime_type(uri, true) == Ok("application/pdf".into()) {
-                if let Ok((_, _, _, _, _, _, Some(frag))) =
-                    glib::Uri::split(uri, glib::UriFlags::ENCODED)
-                {
-                    match frag.rsplit_once('=') {
-                        Some(("page", page)) => {
-                            if let Ok(n) = page.parse::<u32>() {
-                                if n > 0 {
-                                    return Some(LinkDest::new_page((n - 1) as i32));
-                                }
-                            }
+            let Ok((_, _, _, _, _, _, Some(frag))) = glib::Uri::split(uri, glib::UriFlags::ENCODED)
+            else {
+                return None;
+            };
+
+            // We use the standard specified by RFC8118 for all document types.
+            match frag.rsplit_once('=') {
+                Some(("page", page)) => {
+                    if let Ok(n) = page.parse::<u32>() {
+                        if n > 0 {
+                            return Some(LinkDest::new_page((n - 1) as i32));
                         }
-                        Some(("nameddest", named_dest)) => {
-                            return Some(LinkDest::new_named(named_dest))
-                        }
-                        None => return Some(LinkDest::new_page_label(&frag)),
-                        _ => (),
                     }
                 }
+                Some(("nameddest", named_dest)) => return Some(LinkDest::new_named(named_dest)),
+                None => return Some(LinkDest::new_page_label(&frag)),
+                _ => (),
             }
 
             None
@@ -182,7 +186,7 @@ mod imp {
                 // There are windows, but they hold a different document.
                 // Since we don't have security between documents, then
                 // spawn a new process! See:
-                // https://gitlab.gnome.org/GNOME/Incubator/papers/-/issues/104
+                // https://gitlab.gnome.org/GNOME/papers/-/issues/104
                 spawn(Some(file), dest, mode);
                 return;
             }
@@ -212,6 +216,39 @@ mod imp {
             about.set_copyright(&gettext("© 1996–2025 The Papers authors"));
             about.set_translator_credits(&gettext("translator-credits"));
 
+            let adw_version = format!(
+                "{}.{}.{}",
+                adw::major_version(),
+                adw::minor_version(),
+                adw::micro_version()
+            );
+
+            let gtk_version = format!(
+                "{}.{}.{}",
+                gtk::major_version(),
+                gtk::minor_version(),
+                gtk::micro_version()
+            );
+
+            const GIT_COMMIT_ID: &str = git_version!(fallback = VERSION);
+
+            let debug_info = format!(
+                "Document Viewer ({})\n\n\
+                *Flatpak: {}\n\
+                *GTK: {}\n\
+                *Libadwaita: {}\n",
+                GIT_COMMIT_ID,
+                if std::env::var("FLATPAK_ID").is_ok() {
+                    "yes"
+                } else {
+                    "no"
+                },
+                gtk_version,
+                adw_version,
+            );
+
+            about.set_debug_info(&debug_info);
+
             about.set_developers(&[
                 "Martin Kretzschmar <m_kretzschmar@gmx.net>",
                 "Jonathan Blandford <jrb@gnome.org>",
@@ -319,7 +356,7 @@ mod imp {
 
             let obj = self.obj();
 
-            obj.set_option_context_parameter_string(Some(&gettext("Papers")));
+            obj.set_option_context_parameter_string(Some(&gettext("Document Viewer")));
 
             obj.add_main_option(
                 "page-label",
