@@ -603,8 +603,6 @@ impl imp::PpsDocumentView {
                     self,
                     move |_, _, _| {
                         let selected_text = obj.view.selected_text().filter(|t| !t.is_empty());
-                        obj.document_action_group
-                            .change_action_state("toggle-find", &true.into());
                         if let Some(selected_text) = selected_text {
                             obj.search_context
                                 .borrow()
@@ -613,6 +611,8 @@ impl imp::PpsDocumentView {
                                 .set_search_term(&selected_text);
                             obj.find_restart();
                         }
+                        obj.document_action_group
+                            .change_action_state("toggle-find", &true.into());
                     }
                 ))
                 .build(),
@@ -749,14 +749,7 @@ impl imp::PpsDocumentView {
         }
 
         let annot = self.annot.borrow().clone();
-        if let Some(annot) = annot {
-            if let Some(annot) = annot.dynamic_cast_ref::<AnnotationTextMarkup>() {
-                let markup_type = markup_type.expect("no markup_type, but an annot is set");
-                if annot.markup_type() != markup_type {
-                    annot.set_markup_type(markup_type);
-                }
-            }
-        } else if self.view.has_selection() {
+        if self.view.has_selection() {
             let selections = self.view.selections();
             for sel in selections.iter() {
                 let mut start_point = papers_document::Point::new();
@@ -776,6 +769,13 @@ impl imp::PpsDocumentView {
                 );
                 self.annot.replace(annot.as_ref().cloned());
             }
+        } else if let Some(annot) = annot {
+            if let Some(annot) = annot.dynamic_cast_ref::<AnnotationTextMarkup>() {
+                let markup_type = markup_type.expect("no markup_type, but an annot is set");
+                if annot.markup_type() != markup_type {
+                    annot.set_markup_type(markup_type);
+                }
+            }
         }
     }
 
