@@ -37,17 +37,6 @@ mod imp {
 
     #[glib::derived_properties]
     impl ObjectImpl for PpsPageSelector {
-        fn constructed(&self) {
-            self.parent_constructed();
-
-            // Make sure page numbers are always left-to-right
-            self.entry.set_direction(gtk::TextDirection::Ltr);
-            self.entry
-                .first_child()
-                .unwrap()
-                .set_direction(gtk::TextDirection::Ltr);
-        }
-
         fn signals() -> &'static [Signal] {
             static SIGNALS: OnceLock<Vec<Signal>> = OnceLock::new();
             SIGNALS.get_or_init(|| {
@@ -289,7 +278,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct PpsPageSelector(ObjectSubclass<imp::PpsPageSelector>)
-        @extends gtk::Box, gtk::Widget;
+        @extends gtk::Box, gtk::Widget,
+        @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget;
 }
 
 impl PpsPageSelector {
