@@ -45,6 +45,58 @@ mod imp {
             self.document.replace(document);
         }
 
+        fn create_copy_button(&self, text: &str) -> gtk::Button {
+            let copy_button = gtk::Button::builder()
+                .tooltip_text(gettext("Copy to Clipboard"))
+                .icon_name("edit-copy-symbolic")
+                .valign(gtk::Align::Center)
+                .css_classes(["flat"])
+                .build();
+
+            let text_to_copy = text.to_owned();
+            copy_button.connect_clicked(move |button| {
+                let display = button.display();
+                let clipboard = display.clipboard();
+                clipboard.set_text(&text_to_copy);
+            });
+
+            copy_button
+        }
+
+        fn add_list_box_item_with_copy_button(
+            &self,
+            _group: &impl IsA<adw::PreferencesGroup>,
+            label: &str,
+            text: Option<&str>,
+            text_to_copy: &str,
+        ) -> adw::ActionRow {
+            let row = adw::ActionRow::builder()
+                .title(gettext(label))
+                .use_markup(text.is_none())
+                .css_classes(["property"])
+                .subtitle_selectable(true)
+                .build();
+
+            // translators: This is used when a document property does not have
+            // a value.  Examples:
+            // Author: None
+            // Keywords: None
+            let display_text = match text {
+                Some("") | None => gettext("None"),
+                Some(text) => text.to_owned(),
+            };
+
+            row.set_subtitle(&display_text);
+
+            // Add copy button
+            if !text_to_copy.is_empty() {
+                let copy_button = self.create_copy_button(text_to_copy);
+                row.add_suffix(&copy_button);
+            }
+
+            row
+        }
+
         fn refresh_properties(&self, uri: &str, size: u64, info: &DocumentInfo) {
             macro_rules! insert_string_field {
                 ($group:ident, $title:expr, $field:ident) => {{
@@ -72,76 +124,163 @@ mod imp {
 
             let page = adw::PreferencesPage::new();
 
+            let file = gio::File::for_uri(uri);
+
+            // Create buttons box with linked style
+            let button_box = gtk::Box::builder()
+                .orientation(gtk::Orientation::Horizontal)
+                .css_classes(["linked"])
+                .build();
+
+            // Open With button
+            let open_with_button = gtk::Button::builder()
+                .tooltip_text(gettext("Open With…"))
+                .icon_name("external-link-symbolic")
+                .valign(gtk::Align::Center)
+                .css_classes(["flat"])
+                .build();
+
+            let file_for_open = file.clone();
+            open_with_button.connect_clicked(move |_| {
+                let file_launcher = gtk::FileLauncher::new(Some(&file_for_open));
+                file_launcher.set_always_ask(true);
+                file_launcher.launch(gtk::Window::NONE, gio::Cancellable::NONE, |_| {});
+            });
+
+            // Create open folder button
+            let folder_button = gtk::Button::builder()
+                .tooltip_text(gettext("Open File Location"))
+                .icon_name("folder-open-symbolic")
+                .valign(gtk::Align::Center)
+                .css_classes(["flat"])
+                .build();
+
+            let uri_clone = uri.to_string();
+            let file_for_folder = file.clone();
+
+            folder_button.connect_clicked(glib::clone!(
+                #[weak(rename_to = obj)]
+                self,
+                move |_| {
+                    let native = obj.obj().native();
+                    let window = native.and_dynamic_cast_ref::<gtk::Window>();
+                    let uri = uri_clone.clone();
+
+                    // FIXME: It's broken on MacOS due to lack of support in GTK4
+                    gtk::FileLauncher::new(Some(&file_for_folder)).open_containing_folder(
+                        window,
+                        gio::Cancellable::NONE,
+                        move |result| {
+                            if let Err(e) = result {
+                                glib::g_warning!(
+                                    "",
+                                    "Could not show containing folder for \"{}\": {}",
+                                    uri,
+                                    e.message()
+                                );
+                            }
+                        },
+                    );
+                }
+            ));
+
+            // Add buttons to the box
+            button_box.append(&open_with_button);
+            button_box.append(&folder_button);
+
             // File group
             let group = adw::PreferencesGroup::builder()
                 .title(gettext("File"))
+                .header_suffix(&button_box)
                 .build();
 
-            let file = gio::File::for_uri(uri);
+            // Add filename with copy button as first item
+            if let Some(filename) = file.basename() {
+                let filename_str = filename.display().to_string();
+                let filename_row = self.add_list_box_item_with_copy_button(
+                    &group,
+                    &gettext("Name"),
+                    Some(&filename_str),
+                    &filename_str,
+                );
+                group.add(&filename_row);
+            }
 
             if let Some(parent) = file.parent() {
                 // This is a extended attributes exported by document portal
                 const HOST_PATH_ATTR: &str = "xattr::document-portal.host-path";
 
-                let host_parent = file
+                // Get host path from file attributes (if running in Flatpak)
+                let host_path = file
                     .query_info(
                         HOST_PATH_ATTR,
                         gio::FileQueryInfoFlags::NONE,
                         gio::Cancellable::NONE,
                     )
                     .ok()
-                    .and_then(|r| r.attribute_string(HOST_PATH_ATTR))
-                    .and_then(|p| gio::File::for_path(p).parent());
+                    .and_then(|r| r.attribute_string(HOST_PATH_ATTR));
 
-                let text = host_parent
-                    .unwrap_or(parent)
-                    .basename()
+                let host_parent = host_path
+                    .as_ref()
+                    .map(gio::File::for_path)
+                    .and_then(|f| f.parent());
+
+                // Default to regular parent if no host path available
+                let folder_path = host_parent.as_ref().or(Some(&parent));
+
+                // Get folder name for display
+                let folder_name = folder_path
+                    .and_then(|p| p.basename())
                     .map(|p| p.display().to_string())
-                    .unwrap_or(gettext("None"));
+                    .unwrap_or_else(|| gettext("None"));
 
+                // Get folder path for copy operation
+                let folder_path_str = folder_path
+                    .and_then(|p| p.path())
+                    .map(|p| p.display().to_string());
+
+                // Create the folder row
                 let row = adw::ActionRow::builder()
                     .title(gettext("Folder"))
                     .css_classes(["property"])
+                    .subtitle_selectable(true)
                     .build();
 
-                let button = gtk::Button::builder()
-                    .tooltip_text("Open File Location")
-                    .icon_name("folder-open-symbolic")
-                    .valign(gtk::Align::Center)
-                    .css_classes(["flat"])
-                    .build();
+                // Set folder name as subtitle
+                row.set_subtitle(&folder_name);
 
-                let uri = uri.to_string();
+                // Add copy button if we have a folder path
+                if let Some(ref path) = folder_path_str {
+                    let copy_button = self.create_copy_button(path);
+                    row.add_suffix(&copy_button);
+                }
 
-                button.connect_clicked(glib::clone!(
-                    #[weak(rename_to = obj)]
-                    self,
-                    move |_| {
-                        let native = obj.obj().native();
-                        let window = native.and_dynamic_cast_ref::<gtk::Window>();
-                        let uri = uri.clone();
-
-                        // FIXME: It's broken on MacOS due to lack of support in GTK4
-                        gtk::FileLauncher::new(Some(&file)).open_containing_folder(
-                            window,
-                            gio::Cancellable::NONE,
-                            move |result| {
-                                if let Err(e) = result {
-                                    glib::g_warning!(
-                                        "",
-                                        "Could not show containing folder for \"{}\": {}",
-                                        uri,
-                                        e.message()
-                                    );
-                                }
-                            },
-                        );
-                    }
-                ));
-
-                row.set_subtitle(&text);
-                row.add_suffix(&button);
+                // Add folder row to group
                 group.add(&row);
+
+                // Add file path row with copy button
+                if let (Some(folder_path), Some(fname)) = (folder_path_str, file.basename()) {
+                    let path = std::path::Path::new(&folder_path).join(fname);
+                    let full_path = path.display().to_string();
+
+                    let path_row = self.add_list_box_item_with_copy_button(
+                        &group,
+                        &gettext("File Path"),
+                        Some(&full_path),
+                        &full_path,
+                    );
+                    group.add(&path_row);
+                } else if let Some(file_path) = file.path() {
+                    // Fallback to file.path() if we don't have a host path
+                    let full_path = file_path.display().to_string();
+                    let path_row = self.add_list_box_item_with_copy_button(
+                        &group,
+                        &gettext("File Path"),
+                        Some(&full_path),
+                        &full_path,
+                    );
+                    group.add(&path_row);
+                }
             }
 
             if size != 0 {
@@ -240,7 +379,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct PpsPropertiesGeneral(ObjectSubclass<imp::PpsPropertiesGeneral>)
-        @extends adw::Bin, gtk::Widget;
+        @extends adw::Bin, gtk::Widget,
+        @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget;
 }
 
 impl Default for PpsPropertiesGeneral {
