@@ -398,6 +398,12 @@ mod imp {
         fn details_button_toggled(&self) {
             self.listbox.invalidate_filter();
             self.status_listbox.invalidate_filter();
+
+            if self.details_button.is_active() {
+                self.details_button.set_label(&gettext("Hide Details…"));
+            } else {
+                self.details_button.set_label(&gettext("View Details…"));
+            }
         }
 
         #[template_callback]
@@ -442,7 +448,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct PpsPropertiesSignatures(ObjectSubclass<imp::PpsPropertiesSignatures>)
-    @extends gtk::Widget, adw::Bin;
+    @extends gtk::Widget, adw::Bin,
+    @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget;
 }
 
 impl Default for PpsPropertiesSignatures {
