@@ -453,8 +453,11 @@ mod imp {
             debug!("set current selected page to {store_index}");
 
             if self.obj().is_mapped() && self.list_store.n_items() > 0 {
-                self.grid_view
-                    .scroll_to(store_index as u32, gtk::ListScrollFlags::SELECT, None);
+                self.grid_view.scroll_to(
+                    store_index as u32,
+                    gtk::ListScrollFlags::FOCUS | gtk::ListScrollFlags::SELECT,
+                    None,
+                );
             }
 
             self.block_activate.set(false);
@@ -533,7 +536,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct PpsSidebarThumbnails(ObjectSubclass<imp::PpsSidebarThumbnails>)
-        @extends PpsSidebarPage, adw::Bin, gtk::Widget;
+        @extends PpsSidebarPage, adw::Bin, gtk::Widget,
+        @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget;
 }
 
 impl PpsSidebarThumbnails {
